@@ -2,7 +2,7 @@
 u"""
 :Copyright:
 
- Copyright 2015 - 2022
+ Copyright 2015 - 2024
  Andr\xe9 Malo or his licensors, as applicable
 
 :License:
@@ -38,7 +38,7 @@ import pyliblinear as _pyliblinear
 
 
 def test_matrix_dict():
-    """ FeatureMatrix from dicts """
+    """FeatureMatrix from dicts"""
     matrix = _pyliblinear.FeatureMatrix(
         [(1, {3: 4, 1: 7}), (2, {2: 1})],
     )
@@ -50,7 +50,7 @@ def test_matrix_dict():
 
 
 def test_matrix_load_save(tmpdir):
-    """ FeatureMatrix load / save """
+    """FeatureMatrix load / save"""
     matrix = _pyliblinear.FeatureMatrix(
         [(1, {3: 4, 1: 7}), (2, {2: 1})],
     )
@@ -65,7 +65,7 @@ def test_matrix_load_save(tmpdir):
 
 
 def test_matrix_dict_assign():
-    """ FeatureMatrix from dicts with assigned labels """
+    """FeatureMatrix from dicts with assigned labels"""
     matrix = _pyliblinear.FeatureMatrix(
         [{3: 4, 1: 7}, {2: 1}],
         assign_labels=4,
@@ -78,7 +78,7 @@ def test_matrix_dict_assign():
 
 
 def test_matrix_tuple():
-    """ FeatureMatrix from tuples """
+    """FeatureMatrix from tuples"""
     matrix = _pyliblinear.FeatureMatrix(
         [(1, (4, 6)), (2, (1,))],
     )
@@ -90,7 +90,7 @@ def test_matrix_tuple():
 
 
 def test_matrix_tuple_assign():
-    """ FeatureMatrix from tuples with assigned labels """
+    """FeatureMatrix from tuples with assigned labels"""
     matrix = _pyliblinear.FeatureMatrix(
         [(5, 8), (1, 3, 6)],
         assign_labels=4,
@@ -100,7 +100,8 @@ def test_matrix_tuple_assign():
     assert matrix.height == 2
     assert list(matrix.labels()) == [4.0, 4.0]
     assert list(matrix.features()) == [
-        {1: 5.0, 2: 8.0}, {1: 1.0, 2: 3.0, 3: 6.0}
+        {1: 5.0, 2: 8.0},
+        {1: 1.0, 2: 3.0, 3: 6.0},
     ]
 
 
@@ -111,13 +112,13 @@ except NameError:
 
 
 class KeyIterator(object):
-    """ Sequence wrapper providing keys method """
+    """Sequence wrapper providing keys method"""
 
     def __init__(self, vector):
         self._vector = vector
 
     def iterkeys(self):
-        """ Return key iterator """
+        """Return key iterator"""
         return xrange(1, len(self._vector) + 1)
 
     def __getitem__(self, idx):
@@ -125,7 +126,7 @@ class KeyIterator(object):
 
 
 def test_matrix_keys():
-    """ FeatureMatrix from key iterator """
+    """FeatureMatrix from key iterator"""
     matrix = _pyliblinear.FeatureMatrix(
         [(3, KeyIterator((5, 8))), (4, KeyIterator((1, 3, 6)))]
     )
@@ -134,12 +135,13 @@ def test_matrix_keys():
     assert matrix.height == 2
     assert list(matrix.labels()) == [3.0, 4.0]
     assert list(matrix.features()) == [
-        {1: 5.0, 2: 8.0}, {1: 1.0, 2: 3.0, 3: 6.0}
+        {1: 5.0, 2: 8.0},
+        {1: 1.0, 2: 3.0, 3: 6.0},
     ]
 
 
 def test_matrix_keys_assign():
-    """ FeatureMatrix from key iterator and assigned labels """
+    """FeatureMatrix from key iterator and assigned labels"""
     matrix = _pyliblinear.FeatureMatrix(
         [KeyIterator((5, 8)), KeyIterator((1, 3, 6))],
         assign_labels=2.0,
@@ -149,14 +151,16 @@ def test_matrix_keys_assign():
     assert matrix.height == 2
     assert list(matrix.labels()) == [2.0, 2.0]
     assert list(matrix.features()) == [
-        {1: 5.0, 2: 8.0}, {1: 1.0, 2: 3.0, 3: 6.0}
+        {1: 5.0, 2: 8.0},
+        {1: 1.0, 2: 3.0, 3: 6.0},
     ]
 
 
 def test_matrix_from_iterables_dict():
-    """ FeatureMatrix.from_iterables from dicts """
+    """FeatureMatrix.from_iterables from dicts"""
     matrix = _pyliblinear.FeatureMatrix.from_iterables(
-        [2, 3], [{3: 4, 1: 7}, {2: 1}],
+        [2, 3],
+        [{3: 4, 1: 7}, {2: 1}],
     )
 
     assert matrix.width == 3
@@ -166,8 +170,9 @@ def test_matrix_from_iterables_dict():
 
 
 def test_matrix_from_iterables_exc():
-    """ FeatureMatrix.from_iterables raises exception on different lengths """
+    """FeatureMatrix.from_iterables raises exception on different lengths"""
     with raises(ValueError):
         _pyliblinear.FeatureMatrix.from_iterables(
-            [2, 3], [{3: 4, 1: 7}, {2: 1}, {2, 1}],
+            [2, 3],
+            [{3: 4, 1: 7}, {2: 1}, {2, 1}],
         )
